function y=horner(a,x)

% HORNER(a,x) po Hornerjevem pravilu izracuna vrednost 
%   polinoma v tocki x.
%
% Argumenti:
%   a = vektor koeficientov polinoma
%   x = tocka, v kateri racunamo vrednost polinoma (lahko tudi vektor tock)
%
% Rezultat:
%   y = vrednost polinoma p v tocki x

% Bor Plestenjak 2010

y = a(1)*ones(1,length(x));
for k = 2:length(a)
   y = x.*y+a(k);
end
